Index: /trunk/XTIDE_Universal_BIOS/Inc/BootMenu.inc
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Inc/BootMenu.inc	(revision 253)
+++ /trunk/XTIDE_Universal_BIOS/Inc/BootMenu.inc	(revision 254)
@@ -1,4 +1,4 @@
 ; Project name	:	XTIDE Universal BIOS
-; Description	:	Equates used in Boot Menu.
+; Description	:	Equates and structs used in Boot Menu.
 %ifndef BOOTMENU_INC
 %define BOOTMENU_INC
@@ -17,3 +17,28 @@
 
 
+; Boot Menu Information Table. These are generated for all XTIDE Universal
+; BIOS drives. Available only until boot is successfull.
+MAX_HARD_DISK_NAME_LENGTH				EQU		26		; Bytes reserved for drive name
+
+struc BOOTMENUINFO
+	.szDrvName		resb	MAX_HARD_DISK_NAME_LENGTH
+					resb	2		; Zero word (ensures string terminates)
+					resb	8		; padding to make BOOTMENUINFO size an even multiple of DPT size
+endstruc
+
+DPT_BOOTMENUINFO_SIZE_MULTIPLIER  equ	BOOTMENUINFO_size / LARGEST_DPT_SIZE
+
+%ifndef CHECK_FOR_UNUSED_ENTRYPOINTS				
+
+%if BOOTMENUINFO_size % LARGEST_DPT_SIZE <> 0
+%error "BOOTMENUINFO's size must be an even multiple of DPT's size.  Add or remove padding at the bottom of BOOTMENUINFO to bring the two sizes into alignment.  As BOOTMENUINFO is only used at boot time, with plenty of memory to consume, it is OK to waste some space here."
+%endif
+
+%if BOOTMENUINFO.szDrvName <> 0
+%error "BOOTMENUINFO.szDrvName is assumed to be the first member of struc BOOTMENUINFO, in BootMenuPrint_RefreshItem"
+%endif
+
+%endif
+
+
 %endif ; BOOTMENU_INC
Index: /trunk/XTIDE_Universal_BIOS/Inc/BootVars.inc
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Inc/BootVars.inc	(revision 253)
+++ /trunk/XTIDE_Universal_BIOS/Inc/BootVars.inc	(revision 254)
@@ -8,27 +8,4 @@
 BOOT_READ_RETRY_TIMES		EQU		3
 
-
-; Boot Menu Information Table. These are generated for all XTIDE Universal
-; BIOS drives. Available only until boot is successfull.
-LEN_BOOTNFO_DRV		EQU		26		; Bytes reserved for drive name
-struc BOOTNFO
-	.szDrvName		resb	LEN_BOOTNFO_DRV		; Drive name
-					resb	2		; Zero word (ensures string terminates)
-					resb	8		; padding to make BOOTNFO size an even multiple of DPT size
-endstruc
-
-DPT_BOOTNFO_SIZE_MULTIPLIER  equ	BOOTNFO_size / LARGEST_DPT_SIZE
-
-%ifndef CHECK_FOR_UNUSED_ENTRYPOINTS				
-
-%if BOOTNFO_size % LARGEST_DPT_SIZE <> 0
-%error "BOOTNFO's size must be an even multiple of DPT's size.  Add or remove padding at the bottom of BOOTNFO to bring the two sizes into alignment.  As BOOTNFO is only used at boot time, with plenty of memory to consume, it is OK to waste some space here."
-%endif
-
-%if BOOTNFO.szDrvName <> 0
-%error "BOOTNFO.szDrvName is assumed to be the first member of struc BOOTNFO, in BootMenuPrint_RefreshItem"
-%endif
-
-%endif
 
 
Index: unk/XTIDE_Universal_BIOS/Src/Boot/BootInfo.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Boot/BootInfo.asm	(revision 253)
+++ 	(revision )
@@ -1,91 +1,0 @@
-; Project name	:	XTIDE Universal BIOS
-; Description	:	Functions for generating and accessing drive
-;					information to be displayed on boot menu.
-
-; Section containing code
-SECTION .text
-
-;--------------------------------------------------------------------
-; Creates new BOOTNFO struct for detected hard disk.
-;
-; BootInfo_CreateForHardDisk
-;	Parameters:
-;		DL:		Drive number
-;		DS:DI:	Ptr to Disk Parameter Table
-;		ES:SI:	Ptr to 512-byte ATA information read from the drive
-;	Returns:
-;		ES:BX:	Ptr to BOOTNFO (if successful)
-;	Corrupts registers:
-;		AX, BX, CX, DX, DI, SI
-;--------------------------------------------------------------------
-BootInfo_CreateForHardDisk:
-	call	BootInfo_ConvertDPTtoBX		; ES:BX now points to new BOOTNFO
-	push	bx							; Preserve for return
-
-	mov		di, bx						; Starting pointer at beginning of structure
-
-;
-; Store Drive Name
-;		
-	push	ds							; Preserve RAMVARS
-	push	si							; Preserve SI for call to GetTotalSectorCount...
-
-	push	es							; ES copied to DS
-	pop		ds
-
-	add		si, BYTE ATA1.strModel		; DS:SI now points drive name
-	lea		di, [bx+BOOTNFO.szDrvName]	; ES:DI now points to name destination
-	mov		cx, LEN_BOOTNFO_DRV / 2		; Max number of WORDs allowed
-.CopyNextWord:
-	lodsw
-	xchg	al, ah						; Change endianness
-	stosw
-	loop	.CopyNextWord
-	xor		ax, ax						; Zero AX and clear CF
-	stosw								; Terminate with NULL
-
-	pop		si
-	pop		ds
-	pop		bx
-		
-	ret
-
-
-;--------------------------------------------------------------------
-; BootInfo_GetTotalSectorCount
-;	Parameters:
-;		DS:DI:		DPT Pointer
-;	Returns:
-;		BX:DX:AX:	48-bit sector count
-;	Corrupts registers:
-;		CX
-;--------------------------------------------------------------------
-ALIGN JUMP_ALIGN
-BootInfo_GetTotalSectorCount:
-	test	BYTE [di+DPT.bFlagsLow], FLG_DRVNHEAD_LBA
-	jnz		SHORT .ReturnFullCapacity
-	jmp		AH15h_GetSectorCountToBXDXAX
-.ReturnFullCapacity:
-	jmp		AccessDPT_GetLbaSectorCountToBXDXAX
-
-
-;--------------------------------------------------------------------
-; Returns offset to BOOTNFO based on DPT pointer.
-;
-; BootInfo_ConvertDPTtoBX
-;	Parameters:
-;		DS:DI:	DPT Pointer
-;	Returns:
-;		BX:		Offset to BOOTNFO struct
-;	Corrupts registers:
-;		AX
-;--------------------------------------------------------------------
-ALIGN JUMP_ALIGN
-BootInfo_ConvertDPTtoBX:
-	mov		ax, di
-	sub		ax, RAMVARS_size				; subtract off base of DPTs
-	mov		bl, DPT_BOOTNFO_SIZE_MULTIPLIER	; BOOTNFO's are a whole number multiple of DPT size
-	mul		bl								
-	add		ax, BOOTVARS.rgBootNfo			; add base of BOOTNFO
-	xchg	ax, bx
-	ret			
Index: /trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenuInfo.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenuInfo.asm	(revision 254)
+++ /trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenuInfo.asm	(revision 254)
@@ -0,0 +1,89 @@
+; Project name	:	XTIDE Universal BIOS
+; Description	:	Functions for generating and accessing drive
+;					information to be displayed on boot menu.
+
+; Section containing code
+SECTION .text
+
+;--------------------------------------------------------------------
+; Creates new BOOTMENUINFO struct for detected hard disk.
+;
+; BootMenuInfo_CreateForHardDisk
+;	Parameters:
+;		DL:		Drive number
+;		DS:DI:	Ptr to Disk Parameter Table
+;		ES:SI:	Ptr to 512-byte ATA information read from the drive
+;	Returns:
+;		ES:BX:	Ptr to BOOTMENUINFO (if successful)
+;	Corrupts registers:
+;		AX, BX, CX, DX, DI
+;--------------------------------------------------------------------
+BootMenuInfo_CreateForHardDisk:
+	call	BootMenuInfo_ConvertDPTtoBX			; ES:BX now points to new BOOTMENUINFO
+	push	bx									; Preserve for return
+
+	mov		di, bx								; Starting pointer at beginning of structure
+
+	; Store Drive Name
+	push	ds									; Preserve RAMVARS
+	push	si
+
+	push	es									; ES copied to DS
+	pop		ds
+
+	add		si, BYTE ATA1.strModel				; DS:SI now points drive name
+	lea		di, [bx+BOOTMENUINFO.szDrvName]		; ES:DI now points to name destination
+	mov		cx, MAX_HARD_DISK_NAME_LENGTH / 2	; Max number of WORDs allowed
+.CopyNextWord:
+	lodsw
+	xchg	al, ah								; Change endianness
+	stosw
+	loop	.CopyNextWord
+	xor		ax, ax								; Zero AX and clear CF
+	stosw										; Terminate with NULL
+
+	pop		si
+	pop		ds
+	pop		bx
+		
+	ret
+
+
+;--------------------------------------------------------------------
+; BootMenuInfo_GetTotalSectorCount
+;	Parameters:
+;		DS:DI:		DPT Pointer
+;	Returns:
+;		BX:DX:AX:	48-bit sector count
+;	Corrupts registers:
+;		CX
+;--------------------------------------------------------------------
+ALIGN JUMP_ALIGN
+BootMenuInfo_GetTotalSectorCount:
+	test	BYTE [di+DPT.bFlagsLow], FLG_DRVNHEAD_LBA
+	jnz		SHORT .ReturnFullCapacity
+	jmp		AH15h_GetSectorCountToBXDXAX
+.ReturnFullCapacity:
+	jmp		AccessDPT_GetLbaSectorCountToBXDXAX
+
+
+;--------------------------------------------------------------------
+; Returns offset to BOOTMENUINFO based on DPT pointer.
+;
+; BootMenuInfo_ConvertDPTtoBX
+;	Parameters:
+;		DS:DI:	DPT Pointer
+;	Returns:
+;		BX:		Offset to BOOTMENUINFO struct
+;	Corrupts registers:
+;		AX
+;--------------------------------------------------------------------
+ALIGN JUMP_ALIGN
+BootMenuInfo_ConvertDPTtoBX:
+	mov		ax, di
+	sub		ax, RAMVARS_size						; subtract off base of DPTs
+	mov		bl, DPT_BOOTMENUINFO_SIZE_MULTIPLIER	; BOOTMENUINFO's are a whole number multiple of DPT size
+	mul		bl								
+	add		ax, BOOTVARS.rgBootNfo					; add base of BOOTMENUINFO
+	xchg	ax, bx
+	ret			
Index: /trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenuPrint.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenuPrint.asm	(revision 253)
+++ /trunk/XTIDE_Universal_BIOS/Src/Boot/BootMenuPrint.asm	(revision 254)
@@ -27,5 +27,5 @@
 
 	call	FindDPT_ForDriveNumber					; if it is one of ours, print the string in bootnfo
-	call	BootInfo_ConvertDPTtoBX
+	call	BootMenuInfo_ConvertDPTtoBX
 	mov		si, g_szDriveNumBOOTNFO					; special g_szDriveNum that prints from BDA
 	jmp		.go
@@ -197,5 +197,5 @@
 
 	; Get and push total LBA size
-	call	BootInfo_GetTotalSectorCount
+	call	BootMenuInfo_GetTotalSectorCount
 	call	ConvertSectorCountInBXDXAXtoSizeAndPushForFormat		
 	jmp		BootMenuPrintCfg_ForOurDrive
Index: /trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectDrives.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectDrives.asm	(revision 253)
+++ /trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectDrives.asm	(revision 254)
@@ -143,5 +143,5 @@
 	call	CreateDPT_FromAtaInformation
 	jc		SHORT DetectDrives_DriveNotFound
-	call	BootInfo_CreateForHardDisk
+	call	BootMenuInfo_CreateForHardDisk
 	jmp		short DetectPrint_DriveNameFromBootnfoInESBX
 
Index: /trunk/XTIDE_Universal_BIOS/Src/Main.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Main.asm	(revision 253)
+++ /trunk/XTIDE_Universal_BIOS/Src/Main.asm	(revision 254)
@@ -29,5 +29,5 @@
 	%include "RomVars.inc"			; For ROMVARS and IDEVARS structs
 	%include "RamVars.inc"			; For RAMVARS struct
-	%include "BootVars.inc"			; For BOOTVARS and BOOTNFO structs
+	%include "BootVars.inc"			; For BOOTVARS struct
 	%include "BootMenu.inc"			; For Boot Menu
 	%include "IDE_8bit.inc"			; For IDE 8-bit data port macros
@@ -167,5 +167,5 @@
 	%include "FindDPT.asm"			; For finding DPTs
 	%include "AccessDPT.asm"		; For accessing DPTs
-	%include "BootInfo.asm"			; For creating BOOTNFO structs
+	%include "BootMenuInfo.asm"		; For creating BOOTMENUINFO structs
 	%include "AtaID.asm"			; For ATA Identify Device information
 	%include "DetectDrives.asm"		; For detecting IDE drives

Index: /trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectPrint.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectPrint.asm	(revision 253)
+++ /trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectPrint.asm	(revision 254)
@@ -105,5 +105,5 @@
 ; DetectPrint_DriveNameFromBootnfoInESBX
 ;	Parameters:
 ;		ES:BX:	Ptr to BOOTNFO (if drive found)
 ;	Returns:
 ;		Nothing
@@ -115,5 +115,5 @@
 	push	bx
 
-	lea		si, [bx+BOOTNFO.szDrvName]
+	lea		si, [bx+BOOTMENUINFO.szDrvName]
 	mov		bx, es
 	CALL_DISPLAY_LIBRARY PrintNullTerminatedStringFromBXSI
@@ -123,3 +123,2 @@
 	pop		di
 	ret
-
@@ -105,5 +105,5 @@
 ; DetectPrint_DriveNameFromBootnfoInESBX
 ;	Parameters:
-;		ES:BX:	Ptr to BOOTNFO (if drive found)
+;		ES:BX:	Ptr to BOOTMENUINFO (if drive found)
 ;	Returns:
 ;		Nothing